==> haskell-echo-0.1.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-echo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: echo
version: 0.1.3
id: echo-0.1.3-K6IolejTib2L02PL91cWPC
key: echo-0.1.3-K6IolejTib2L02PL91cWPC
license: BSD3
copyright: (C) 2016-2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
stability: Provisional
homepage: https://github.com/RyanGlScott/echo
synopsis: A cross-platform, cross-console way to handle echoing terminal input
description:
    The @base@ library exposes the @hGetEcho@ and @hSetEcho@ functions
    for querying and setting echo status, but unfortunately, neither
    function works with MinTTY consoles on Windows. This is a serious
    issue, since @hGetEcho@ and @hSetEcho@ are often used to disable
    input echoing when a program prompts for a password, so many
    programs will reveal your password as you type it on MinTTY!
    .
    This library provides an alternative interface which works
    with both MinTTY and other consoles. An example is included
    which demonstrates how one might prompt for a password using
    this library. To build it, make sure to configure with the
    @-fexample@ flag.
category: System
author: Ryan Scott
exposed: True
exposed-modules:
    System.IO.Echo System.IO.Echo.Internal
abi: e5347ab75c47e3a84a6225355c00e2b8
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/echo-0.1.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/echo-0.1.3
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/echo-0.1.3
hs-libraries: HSecho-0.1.3-K6IolejTib2L02PL91cWPC
depends:
    base-4.9.1.0 process-1.4.3.0
haddock-interfaces: /usr/share/doc/haskell-echo/html/echo.haddock
haddock-html: /usr/share/doc/haskell-echo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-echo-0.1.3-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-echo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: echo
version: 0.1.3
id: echo-0.1.3-Bg2uuLn1Ivq5ZBFhk7SHx5
key: echo-0.1.3-Bg2uuLn1Ivq5ZBFhk7SHx5
license: BSD3
copyright: (C) 2016-2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
stability: Provisional
homepage: https://github.com/RyanGlScott/echo
synopsis: A cross-platform, cross-console way to handle echoing terminal input
description:
    The @base@ library exposes the @hGetEcho@ and @hSetEcho@ functions
    for querying and setting echo status, but unfortunately, neither
    function works with MinTTY consoles on Windows. This is a serious
    issue, since @hGetEcho@ and @hSetEcho@ are often used to disable
    input echoing when a program prompts for a password, so many
    programs will reveal your password as you type it on MinTTY!
    .
    This library provides an alternative interface which works
    with both MinTTY and other consoles. An example is included
    which demonstrates how one might prompt for a password using
    this library. To build it, make sure to configure with the
    @-fexample@ flag.
category: System
author: Ryan Scott
exposed: True
indefinite: False
exposed-modules:
    System.IO.Echo System.IO.Echo.Internal
abi: 5bf0670efac9dd68edbeaea005658962
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/echo-0.1.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/echo-0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/echo-0.1.3
hs-libraries: HSecho-0.1.3-Bg2uuLn1Ivq5ZBFhk7SHx5
depends:
    base-4.10.0.0 process-1.6.1.0
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             process-1.6.1.0=d01a8ca2c6610f40dfd0fe25f50afb10
haddock-interfaces: /usr/share/doc/haskell-echo/html/echo.haddock
haddock-html: /usr/share/doc/haskell-echo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
